@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: binhex.c,v 1.8 1997/08/25 03:51:09 rob Exp $
+ * $Id: binhex.c,v 1.10 1998/01/08 21:11:27 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -101,7 +101,7 @@ int bh_start(int fd)
       return -1;
     }
 
-  file = fdopen(dupfd, "a");
+  file = fdopen(dupfd, "ab");
   if (file == 0)
     {
       ERROR(errno, "error creating output buffer");
@@ -352,7 +352,7 @@ int bh_open(int fd)
       return -1;
     }
 
-  file = fdopen(dupfd, "r");
+  file = fdopen(dupfd, "rb");
   if (file == 0)
     {
       ERROR(errno, "error creating input buffer");
