@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: copyin.c,v 1.13 1997/11/08 20:17:46 rob Exp $
+ * $Id: copyin.c,v 1.14 1998/01/08 21:11:34 rob Exp rob $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -223,7 +223,7 @@ int do_binh(hfsfile *ofile, unsigned long dsize, unsigned long rsize)
 static
 int do_text(int ifile, hfsfile *ofile)
 {
-  unsigned char buf[HFS_BLOCKSZ * 4], *ptr;
+  char buf[HFS_BLOCKSZ * 4], *ptr;
   long chunk, bytes;
   int len;
 
