@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hformat.c,v 1.12 1997/11/11 21:27:48 rob Exp $
+ * $Id: hformat.c,v 1.15 1998/01/08 21:13:23 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -47,11 +47,9 @@ extern int optind;
  * DESCRIPTION:	display usage message
  */
 static
-int usage(void)
+void usage(void)
 {
   fprintf(stderr, "Usage: %s [-f] [-l label] path [partition-no]\n", argv0);
-
-  return 1;
 }
 
 /*
@@ -79,7 +77,8 @@ hfsvol *do_format(const char *path, int partno, const char *vname)
  */
 int hformat_main(int argc, char *argv[])
 {
-  const char *vname, *path;
+  const char *vname;
+  char *path = 0;
   hfsvol *vol;
   hfsvolent ent;
   int nparts, partno, options = 0, result = 0;
@@ -97,7 +96,8 @@ int hformat_main(int argc, char *argv[])
       switch (opt)
 	{
 	case '?':
-	  return usage();
+	  usage();
+	  goto fail;
 
 	case 'f':
 	  options |= O_FORCE;
@@ -110,11 +110,21 @@ int hformat_main(int argc, char *argv[])
     }
 
   if (argc - optind < 1 || argc - optind > 2)
-    return usage();
+    {
+      usage();
+      goto fail;
+    }
 
-  path = argv[optind];
+  path = hfsutil_abspath(argv[optind]);
+  if (path == 0)
+    {
+      fprintf(stderr, "%s: not enough memory\n", argv0);
+      goto fail;
+    }
 
+  suid_enable();
   nparts = hfs_nparts(path);
+  suid_disable();
 
   if (argc - optind == 2)
     {
@@ -131,7 +141,7 @@ int hformat_main(int argc, char *argv[])
 	    {
 	      fprintf(stderr, "%s: medium is partitioned; "
 		      "select partition > 0 or use -f\n", argv0);
-	      return 1;
+	      goto fail;
 	    }
 	}
     }
@@ -142,7 +152,7 @@ int hformat_main(int argc, char *argv[])
 	  fprintf(stderr,
 		  "%s: must specify partition number (%d available)\n",
 		  argv0, nparts);
-	  return 1;
+	  goto fail;
 	}
       else if (nparts == -1)
 	partno = 0;
@@ -154,7 +164,7 @@ int hformat_main(int argc, char *argv[])
   if (vol == 0)
     {
       hfsutil_perror(path);
-      return 1;
+      goto fail;
     }
 
   hfs_vstat(vol, &ent);
@@ -168,5 +178,13 @@ int hformat_main(int argc, char *argv[])
 
   hfsutil_unmount(vol, &result);
 
+  free(path);
+
   return result;
+
+fail:
+  if (path)
+    free(path);
+
+  return 1;
 }
