@@ -1,7 +1,6 @@
-###############################################################################
 #
 # hfsutils - tools for reading and writing Macintosh HFS volumes
-# Copyright (C) 1996, 1997 Robert Leslie
+# Copyright (C) 1996-1998 Robert Leslie
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +16,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: hfs.tcl,v 1.12 1997/11/05 05:27:13 rob Exp $
+# $Id: hfs.tcl,v 1.15 1998/01/08 21:20:11 rob Exp rob $
 #
-###############################################################################
 
 proc ctime {secs} {
     return [clock format $secs -format "%c"]
@@ -142,19 +140,6 @@ proc hcd {{path ""}} {
     $vol cd $path
 }
 
-proc assoc {list var} {
-    upvar $var array
-
-    foreach elt $list {
-	if {[info exists key]} {
-	    set array($key) $elt
-	    unset key
-	} else {
-	    set key $elt
-	}
-    }
-}
-
 proc timestr {secs} {
     set ctime [ctime $secs]
 
@@ -179,7 +164,7 @@ proc hdir {{path ":"}} {
     set path [lindex $globbed 0]
 
     foreach ent [$vol dir $path] {
-	assoc $ent item
+	array set item $ent
 
 	if {$item(kind) == "directory"} {
 	    puts stdout [format "d%s %9lu item%s               %s %s"  \
@@ -211,7 +196,7 @@ proc hstat {{path ":"}} {
     }
     set path [lindex $globbed 0]
 
-    assoc [$vol stat $path] item
+    array set item [$vol stat $path]
 
     foreach elt [lsort [array names item]] {
 	if {[regexp {date$} $elt]} {
@@ -311,7 +296,7 @@ proc hcopyout {path {dest "."} {mode ""}} {
     set path [lindex $globbed 0]
 
     if {[string length $mode] == 0} {
-	assoc [$vol stat $path] item
+	array set item [$vol stat $path]
 
 	if {$item(kind) == "directory"} {
 	    error "can't copy whole directories"
@@ -405,12 +390,16 @@ proc ? {args} {
 
 ###############################################################################
 
+proc version {} {
+    puts stdout "[hfs version] - [hfs copyright]"
+}
+
 proc license {} {
     puts -nonewline stdout "\n[hfs license]"
 }
 
-proc version {} {
-    puts stdout "[hfs version] - [hfs copyright]"
+proc author {} {
+    puts stdout [hfs author]
 }
 
 if {[string compare [lindex $argv 0] "--license"] == 0} {
