@@ -1,6 +1,6 @@
 /*
  * hfsck - tool for checking and repairing the integrity of HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,10 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: ck_mdb.c,v 1.4 1997/11/11 23:16:54 rob Exp $
+ * $Id: ck_mdb.c,v 1.4 1997/11/11 23:16:54 rob Exp rob $
  */
 
 # include <stdio.h>
+# include <string.h>
 # include <time.h>
 
 # include "hfsck.h"
@@ -69,6 +70,11 @@ int ck_mdb(hfsvol *vol)
 	  printf("%s BBSPARED", flag ? " |" : "");
 	  flag = 1;
 	}
+      if (mdb->drAtrb & HFS_ATRB_BVINCONSIS)
+	{
+	  printf("%s BVINCONSIS", flag ? " |" : "");
+	  flag = 1;
+	}
       if (mdb->drAtrb & HFS_ATRB_COPYPROT)
 	{
 	  printf("%s COPYPROT", flag ? " |" : "");
@@ -174,5 +180,56 @@ int ck_mdb(hfsvol *vol)
       vol->flags |= HFS_VOL_UPDATE_MDB;
     }
 
+  /* mdb->drAtrb */
+  /* mdb->drNmFls */
+
+  /* mdb->drVBMSt */
+
+  if (mdb->drVBMSt != 3 &&
+      ask("Volume bitmap starts at unusual location (%u), not 3"))
+    {
+      mdb->drVBMSt = 3;
+      vol->flags |= HFS_VOL_UPDATE_MDB;
+    }
+
+  /* mdb->drAllocPtr */
+  /* ... */
+
+  /* initialize other important fields */
+
+  vol->lpa = vol->mdb.drAlBlkSiz >> HFS_BLOCKSZ_BITS;
+
+  /* extents pseudo-file structs */
+
+  vol->ext.f.cat.u.fil.filStBlk   = vol->mdb.drXTExtRec[0].xdrStABN;
+  vol->ext.f.cat.u.fil.filLgLen   = vol->mdb.drXTFlSize;
+  vol->ext.f.cat.u.fil.filPyLen   = vol->mdb.drXTFlSize;
+
+  vol->ext.f.cat.u.fil.filCrDat   = vol->mdb.drCrDate;
+  vol->ext.f.cat.u.fil.filMdDat   = vol->mdb.drLsMod;
+
+  vol->ext.f.cat.u.fil.filClpSize = vol->mdb.drXTClpSiz;
+
+  memcpy(&vol->ext.f.cat.u.fil.filExtRec,
+	 &vol->mdb.drXTExtRec, sizeof(ExtDataRec));
+
+  f_selectfork(&vol->ext.f, fkData);
+
+  /* catalog pseudo-file structs */
+
+  vol->cat.f.cat.u.fil.filStBlk   = vol->mdb.drCTExtRec[0].xdrStABN;
+  vol->cat.f.cat.u.fil.filLgLen   = vol->mdb.drCTFlSize;
+  vol->cat.f.cat.u.fil.filPyLen   = vol->mdb.drCTFlSize;
+
+  vol->cat.f.cat.u.fil.filCrDat   = vol->mdb.drCrDate;
+  vol->cat.f.cat.u.fil.filMdDat   = vol->mdb.drLsMod;
+
+  vol->cat.f.cat.u.fil.filClpSize = vol->mdb.drCTClpSiz;
+
+  memcpy(&vol->cat.f.cat.u.fil.filExtRec,
+	 &vol->mdb.drCTExtRec, sizeof(ExtDataRec));
+
+  f_selectfork(&vol->cat.f, fkData);
+
   return 0;
 }
