@@ -1,6 +1,6 @@
 /*
  * hfsck - tool for checking and repairing the integrity of HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: main.c,v 1.9 1997/11/11 21:36:47 rob Exp $
+ * $Id: main.c,v 1.9 1997/11/11 21:36:47 rob Exp rob $
  */
 
 # include <stdio.h>
@@ -42,7 +42,8 @@ extern int optind;
 static
 int usage(char *argv[])
 {
-  fprintf(stderr, "Usage: %s [-v] [-n] [-a] device-path\n", argv[0]);
+  fprintf(stderr, "Usage: %s [-v] [-n] [-a] device-path [partition-no]\n",
+	  argv[0]);
 
   return 1;
 }
@@ -54,7 +55,7 @@ int usage(char *argv[])
 int main(int argc, char *argv[])
 {
   char *path;
-  int pnum, result;
+  int nparts, pnum, result;
   hfsvol vol;
 
   suid_init();
@@ -103,21 +104,46 @@ int main(int argc, char *argv[])
 	}
     }
 
-  if (argc - optind != 1)
+  if (argc - optind < 1 ||
+      argc - optind > 2)
     return usage(argv);
 
   path = argv[optind];
-  pnum = 1;
+
+  suid_enable();
+  nparts = hfs_nparts(path);
+  suid_disable();
+
+  if (argc - optind == 2)
+    pnum = atoi(argv[optind + 1]);
+  else
+    {
+      if (nparts > 1)
+	{
+	  fprintf(stderr, "%s: must specify partition number\n", argv[0]);
+	  return 1;
+	}
+      else if (nparts == -1)
+	pnum = 0;
+      else
+	pnum = 1;
+    }
 
   v_init(&vol, 0);
 
   if (REPAIR)
     {
+      suid_enable();
       result = v_open(&vol, path, HFS_MODE_RDWR);
+      suid_disable();
+
       if (result == -1)
 	{
 	  vol.flags |= HFS_VOL_READONLY;
+
+	  suid_enable();
 	  result = v_open(&vol, path, HFS_MODE_RDONLY);
+	  suid_disable();
 	}
     }
 
@@ -136,7 +162,7 @@ int main(int argc, char *argv[])
     }
 
   if (v_geometry(&vol, pnum) == -1 ||
-      v_readmdb(&vol) == -1)
+      l_getmdb(&vol, &vol.mdb, 0) == -1)
     {
       perror(path);
       v_close(&vol);
@@ -145,12 +171,7 @@ int main(int argc, char *argv[])
 
   result = hfsck(&vol);
 
-  if (result == 0 && v_flush(&vol, 1) == -1)
-    {
-      perror("flushing volume");
-      v_close(&vol);
-      return 1;
-    }
+  vol.flags |= HFS_VOL_MOUNTED;
 
   if (v_close(&vol) == -1)
     {
