@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: block.c,v 1.22 1997/11/07 16:48:46 rob Exp $
+ * $Id: block.c,v 1.25 1998/01/08 21:15:02 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -45,10 +45,7 @@ int b_init(hfsvol *vol)
   bcache *cache;
   int i;
 
-# ifdef DEBUG
-  if (vol->cache)
-    abort();
-# endif
+  ASSERT(vol->cache == 0);
 
   cache = ALLOC(bcache, 1);
   if (cache == 0)
@@ -98,7 +95,7 @@ fail:
  */
 void b_showstats(const bcache *cache)
 {
-  fprintf(stderr, "CACHE: vol 0x%lx \"%s\" hit/miss ratio = %.1f%%\n",
+  fprintf(stderr, "BLOCK: CACHE vol 0x%lx \"%s\" hit/miss ratio = %.1f%%\n",
 	  (unsigned long) cache->vol, cache->vol->mdb.drVN,
 	  cache->hits * 100.0 / cache->misses);
 }
@@ -112,7 +109,7 @@ void b_dumpcache(const bcache *cache)
   const bucket *b;
   int i;
 
-  fprintf(stderr, "CACHE DUMP:\n");
+  fprintf(stderr, "BLOCK CACHE DUMP:\n");
 
   for (i = 0, b = cache->tail->cnext; i < HFS_CACHESZ; ++i, b = b->cnext)
     {
@@ -128,7 +125,7 @@ void b_dumpcache(const bcache *cache)
 
   fprintf(stderr, "\n");
 
-  fprintf(stderr, "HASH DUMP:\n");
+  fprintf(stderr, "BLOCK HASH DUMP:\n");
 
   for (i = 0; i < HFS_HASHSZ; ++i)
     {
@@ -332,7 +329,7 @@ int b_flush(hfsvol *vol)
   bucket *chain[HFS_CACHESZ];
   int i;
 
-  if (cache == 0)
+  if (cache == 0 || (vol->flags & HFS_VOL_READONLY))
     goto done;
 
   for (i = 0; i < HFS_CACHESZ; ++i)
@@ -341,11 +338,12 @@ int b_flush(hfsvol *vol)
   if (flushbuckets(vol, chain, HFS_CACHESZ) == -1)
     goto fail;
 
+done:
 # ifdef DEBUG
-  b_showstats(cache);
+  if (cache)
+    b_showstats(cache);
 # endif
 
-done:
   return 0;
 
 fail:
@@ -408,7 +406,7 @@ int reuse(bcache *cache, bucket *b, unsigned long bnum)
 
 # ifdef DEBUG
   if (INUSE(b))
-    fprintf(stderr, "CACHE: reusing bucket containing "
+    fprintf(stderr, "BLOCK: CACHE reusing bucket containing "
 	    "vol 0x%lx block %lu:%u\n",
 	    (unsigned long) cache->vol, b->bnum, b->count);
 # endif
@@ -590,7 +588,8 @@ int b_readpb(hfsvol *vol, unsigned long bnum, block *bp, unsigned int blen)
   long nbytes;
 
 # ifdef DEBUG
-  fprintf(stderr, "READ: vol 0x%lx block %lu", (unsigned long) vol, bnum);
+  fprintf(stderr, "BLOCK: READ vol 0x%lx block %lu",
+	  (unsigned long) vol, bnum);
   if (blen > 1)
     fprintf(stderr, "+%u[..%lu]\n", blen - 1, bnum + blen - 1);
   else
@@ -628,7 +627,8 @@ int b_writepb(hfsvol *vol, unsigned long bnum, const block *bp,
   long nbytes;
 
 # ifdef DEBUG
-  fprintf(stderr, "WRITE: vol 0x%lx block %lu", (unsigned long) vol, bnum);
+  fprintf(stderr, "BLOCK: WRITE vol 0x%lx block %lu",
+	  (unsigned long) vol, bnum);
   if (blen > 1)
     fprintf(stderr, "+%u[..%lu]\n", blen - 1, bnum + blen - 1);
   else
