@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: btree.c,v 1.18 1997/11/07 16:48:34 rob Exp $
+ * $Id: btree.c,v 1.20 1998/01/08 21:15:06 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -45,6 +45,11 @@ int bt_getnode(node *np)
   const byte *ptr;
   int i;
 
+# ifdef DEBUG
+  fprintf(stderr, "BTREE: GET vol \"%s\" btree \"%s\" node %d\n",
+	  bt->f.vol->mdb.drVN, bt->f.name, np->nnum);
+# endif
+
   /* verify the node exists and is marked as in-use */
 
   if (np->nnum > 0 && np->nnum >= bt->hdr.bthNNodes)
@@ -91,6 +96,11 @@ int bt_putnode(node *np)
   byte *ptr;
   int i;
 
+# ifdef DEBUG
+  fprintf(stderr, "BTREE: PUT vol \"%s\" btree \"%s\" node %d\n",
+	  bt->f.vol->mdb.drVN, bt->f.name, np->nnum);
+# endif
+
   /* verify the node exists and is marked as in-use */
 
   if (np->nnum > 0 && np->nnum >= bt->hdr.bthNNodes)
@@ -230,13 +240,10 @@ int bt_writehdr(btree *bt)
   unsigned long mapsz, nnum;
   int i;
 
-# ifdef DEBUG
-  if (bt->hdrnd.bt != bt ||
-      bt->hdrnd.nnum != 0 ||
-      bt->hdrnd.nd.ndType != ndHdrNode ||
-      bt->hdrnd.nd.ndNRecs != 3)
-    abort();
-# endif
+  ASSERT(bt->hdrnd.bt == bt &&
+	 bt->hdrnd.nnum == 0 &&
+	 bt->hdrnd.nd.ndType == ndHdrNode &&
+	 bt->hdrnd.nd.ndNRecs == 3);
 
   ptr = HFS_NODEREC(bt->hdrnd, 0);
 
