@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hfs.c,v 1.22 1997/11/08 03:42:04 rob Exp $
+ * $Id: hfs.c,v 1.27 1998/01/08 21:15:15 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -55,9 +55,6 @@ int validvname(const char *name)
 {
   int len;
 
-  if (strchr(name, ':'))
-    ERROR(EINVAL, "volume name may not contain colons");
-
   len = strlen(name);
   if (len < 1)
     ERROR(EINVAL, "volume name cannot be empty");
@@ -65,6 +62,9 @@ int validvname(const char *name)
     ERROR(ENAMETOOLONG,
 	  "volume name can be at most " STR(HFS_MAX_VLEN) " chars");
 
+  if (strchr(name, ':'))
+    ERROR(EINVAL, "volume name may not contain colons");
+
   return 1;
 
 fail:
@@ -92,21 +92,6 @@ fail:
   return -1;
 }
 
-/*
- * NAME:	destructvol()
- * DESCRIPTION:	free memory consumed by a volume descriptor
- */
-static
-void destructvol(hfsvol *vol)
-{
-  FREE(vol->vbm);
-
-  FREE(vol->ext.map);
-  FREE(vol->cat.map);
-
-  FREE(vol);
-}
-
 /* High-Level Volume Routines ============================================== */
 
 /*
@@ -121,8 +106,7 @@ hfsvol *hfs_mount(const char *path, int pnum, int flags)
 
   for (check = hfs_mounts; check; check = check->next)
     {
-      if ((check->pnum == 0 || check->pnum == pnum) &&
-	  v_same(check, path) == 1)
+      if (check->pnum == pnum && v_same(check, path) == 1)
 	{
 	  /* verify compatible read/write mode */
 
@@ -163,31 +147,13 @@ hfsvol *hfs_mount(const char *path, int pnum, int flags)
 	goto fail;
     }
 
-  if (v_geometry(vol, pnum) == -1)
+  /* mount the volume */
+
+  if (v_geometry(vol, pnum) == -1 ||
+      v_mount(vol) == -1)
     goto fail;
 
-  /* read the MDB, volume bitmap, and extents/catalog B*-tree headers */
-
-  if (v_readmdb(vol) == -1 ||
-      v_readvbm(vol) == -1 ||
-      bt_readhdr(&vol->ext) == -1 ||
-      bt_readhdr(&vol->cat) == -1)
-    goto fail;
-
-  if (! (vol->mdb.drAtrb & HFS_ATRB_UMOUNTED))
-    {
-      /* volume was not cleanly unmounted; scavenge free-space */
-
-      if (v_scavenge(vol) == -1)
-	goto fail;
-    }
-
-  if (vol->mdb.drAtrb & HFS_ATRB_SLOCKED)
-    vol->flags |= HFS_VOL_READONLY;
-  else if (vol->flags & HFS_VOL_READONLY)
-    vol->mdb.drAtrb |= HFS_ATRB_HLOCKED;
-  else
-    vol->mdb.drAtrb &= ~HFS_ATRB_HLOCKED;
+  /* add to linked list of volumes */
 
   vol->prev = 0;
   vol->next = hfs_mounts;
@@ -207,7 +173,7 @@ fail:
   if (vol)
     {
       v_close(vol);
-      destructvol(vol);
+      FREE(vol);
     }
 
   return 0;
@@ -230,7 +196,7 @@ int hfs_flush(hfsvol *vol)
 	goto fail;
     }
 
-  if (v_flush(vol, 0) == -1)
+  if (v_flush(vol) == -1)
     goto fail;
 
   return 0;
@@ -264,7 +230,7 @@ int hfs_umount(hfsvol *vol)
 
   if (--vol->refs)
     {
-      result = v_flush(vol, 0);
+      result = v_flush(vol);
       goto done;
     }
 
@@ -282,7 +248,9 @@ int hfs_umount(hfsvol *vol)
 	result = -1;
     }
 
-  if (v_flush(vol, 1) == -1)
+  /* close medium */
+
+  if (v_close(vol) == -1)
     result = -1;
 
   /* remove from linked list of volumes */
@@ -297,20 +265,12 @@ int hfs_umount(hfsvol *vol)
   if (vol == curvol)
     curvol = 0;
 
-  /* close medium */
-
-  if (v_close(vol) == -1)
-    goto fail;
-
-  destructvol(vol);
+  FREE(vol);
 
 done:
   return result;
 
 fail:
-  if (vol)
-    destructvol(vol);
-
   return -1;
 }
 
@@ -1589,6 +1549,7 @@ int hfs_nparts(const char *path)
   return nparts;
 
 fail:
+  v_close(&vol);
   return -1;
 }
 
@@ -1614,9 +1575,7 @@ int hfs_format(const char *path, int pnum, const char *vname,
   btree *cat = &vol.cat;
   unsigned int vbmsz;
   int i;
-  block vbm[16];
   unsigned int *badalloc = 0;
-  byte *map;
 
   v_init(&vol, HFS_VOL_USECACHE);
 
@@ -1676,8 +1635,11 @@ int hfs_format(const char *path, int pnum, const char *vname,
 
   /* initialize volume bitmap */
 
-  memset(vbm, 0, sizeof(vbm));
-  vol.vbm = vbm;
+  vol.vbm = ALLOC(block, vbmsz);
+  if (vol.vbm == 0)
+    ERROR(ENOMEM, 0);
+
+  memset(vol.vbm, 0, vbmsz << HFS_BLOCKSZ_BITS);
 
   /* perform initial bad block sparing */
 
@@ -1742,14 +1704,13 @@ int hfs_format(const char *path, int pnum, const char *vname,
   for (i = 0; i < 76; ++i)
     ext->hdr.bthResv[i] = 0;
 
-  map = ALLOC(byte, HFS_MAP1SZ);
-  if (map == 0)
+  ext->map = ALLOC(byte, HFS_MAP1SZ);
+  if (ext->map == 0)
     ERROR(ENOMEM, 0);
 
-  memset(map, 0, HFS_MAP1SZ);
-  BMSET(map, 0);
+  memset(ext->map, 0, HFS_MAP1SZ);
+  BMSET(ext->map, 0);
 
-  ext->map     = map;
   ext->mapsz   = HFS_MAP1SZ;
   ext->flags   = HFS_BT_UPDATE_HDR;
 
@@ -1779,14 +1740,13 @@ int hfs_format(const char *path, int pnum, const char *vname,
   for (i = 0; i < 76; ++i)
     cat->hdr.bthResv[i] = 0;
 
-  map = ALLOC(byte, HFS_MAP1SZ);
-  if (map == 0)
+  cat->map = ALLOC(byte, HFS_MAP1SZ);
+  if (cat->map == 0)
     ERROR(ENOMEM, 0);
 
-  memset(map, 0, HFS_MAP1SZ);
-  BMSET(map, 0);
+  memset(cat->map, 0, HFS_MAP1SZ);
+  BMSET(cat->map, 0);
 
-  cat->map     = map;
   cat->mapsz   = HFS_MAP1SZ;
   cat->flags   = HFS_BT_UPDATE_HDR;
 
@@ -1853,15 +1813,12 @@ int hfs_format(const char *path, int pnum, const char *vname,
 
   /* flush other volume state */
 
-  vol.flags |= HFS_VOL_UPDATE_MDB | HFS_VOL_UPDATE_ALTMDB | HFS_VOL_UPDATE_VBM;
+  vol.flags |= HFS_VOL_MOUNTED |
+    HFS_VOL_UPDATE_MDB | HFS_VOL_UPDATE_VBM | HFS_VOL_UPDATE_ALTMDB;
 
-  if (v_flush(&vol, 1) == -1 ||
-      v_close(&vol) == -1)
+  if (v_close(&vol) == -1)
     goto fail;
 
-  FREE(ext->map);
-  FREE(cat->map);
-
   FREE(badalloc);
 
   return 0;
@@ -1869,9 +1826,6 @@ int hfs_format(const char *path, int pnum, const char *vname,
 fail:
   v_close(&vol);
 
-  FREE(ext->map);
-  FREE(cat->map);
-
   FREE(badalloc);
 
   return -1;
