@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: libhfs.h,v 1.19 1997/11/07 16:49:01 rob Exp $
+ * $Id: libhfs.h,v 1.22 1998/01/08 21:15:17 rob Exp $
  */
 
 # include "hfs.h"
@@ -26,6 +26,12 @@ extern int errno;
 # define ERROR(code, str)  \
     do { hfs_error = (str), errno = (code); goto fail; } while (0)
 
+# ifdef DEBUG
+#  define ASSERT(cond)	do { if (! (cond)) abort(); } while (0)
+# else
+#  define ASSERT(cond)	/* nothing */
+# endif
+
 # define SIZE(type, n)		((size_t) (sizeof(type) * (n)))
 # define ALLOC(type, n)		((type *) malloc(SIZE(type, n)))
 # define ALLOCX(type, n)	((n) ? ALLOC(type, n) : (type *) 0)
@@ -34,7 +40,7 @@ extern int errno;
 # define REALLOC(ptr, type, n)  \
     ((type *) ((ptr) ? realloc(ptr, SIZE(type, n)) : malloc(SIZE(type, n))))
 # define REALLOCX(ptr, type, n)  \
-    ((n) ? REALLOC(type, n) : (FREE(ptr), (type *) 0))
+    ((n) ? REALLOC(ptr, type, n) : (FREE(ptr), (type *) 0))
 
 # define BMTST(bm, num)  \
     (((byte *) (bm))[(num) >> 3]  &  (0x80 >> ((num) & 0x07)))
@@ -66,9 +72,9 @@ typedef struct _bucket_ {
 # define HFS_BUCKET_INUSE	0x01
 # define HFS_BUCKET_DIRTY	0x02
 
-# define HFS_CACHESZ	128
-# define HFS_HASHSZ	32
-# define HFS_BLOCKBUFSZ	16
+# define HFS_CACHESZ		128
+# define HFS_HASHSZ		32
+# define HFS_BLOCKBUFSZ		16
 
 typedef struct {
   struct _hfsvol_ *vol;		/* volume to which cache belongs */
@@ -395,8 +401,9 @@ struct _hfsvol_ {
 };
 
 # define HFS_VOL_OPEN		0x01
-# define HFS_VOL_READONLY	0x02
-# define HFS_VOL_USECACHE	0x04
+# define HFS_VOL_MOUNTED	0x02
+# define HFS_VOL_READONLY	0x04
+# define HFS_VOL_USECACHE	0x08
 
 # define HFS_VOL_UPDATE_MDB	0x10
 # define HFS_VOL_UPDATE_ALTMDB	0x20
