@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: low.c,v 1.21 1997/11/07 16:49:40 rob Exp $
+ * $Id: low.c,v 1.23 1998/01/08 21:15:19 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -60,10 +60,7 @@ int l_getddr(hfsvol *vol, Block0 *ddr)
   for (i = 0; i < 243; ++i)
     d_fetchsw(&ptr, &ddr->ddPad[i]);
 
-# ifdef DEBUG
-  if (ptr - b != HFS_BLOCKSZ)
-    abort();
-# endif
+  ASSERT(ptr - b == HFS_BLOCKSZ);
 
   return 0;
 
@@ -95,10 +92,7 @@ int l_putddr(hfsvol *vol, const Block0 *ddr)
   for (i = 0; i < 243; ++i)
     d_storesw(&ptr, ddr->ddPad[i]);
 
-# ifdef DEBUG
-  if (ptr - b != HFS_BLOCKSZ)
-    abort();
-# endif
+  ASSERT(ptr - b == HFS_BLOCKSZ);
 
   if (b_writepb(vol, 0, &b, 1) == -1)
     goto fail;
@@ -154,10 +148,7 @@ int l_getpmentry(hfsvol *vol, Partition *map, unsigned long bnum)
   for (i = 0; i < 188; ++i)
     d_fetchsw(&ptr, &map->pmPad[i]);
 
-# ifdef DEBUG
-  if (ptr - b != HFS_BLOCKSZ)
-    abort();
-# endif
+  ASSERT(ptr - b == HFS_BLOCKSZ);
 
   return 0;
 
@@ -207,10 +198,7 @@ int l_putpmentry(hfsvol *vol, const Partition *map, unsigned long bnum)
   for (i = 0; i < 188; ++i)
     d_storesw(&ptr, map->pmPad[i]);
 
-# ifdef DEBUG
-  if (ptr - b != HFS_BLOCKSZ)
-    abort();
-# endif
+  ASSERT(ptr - b == HFS_BLOCKSZ);
 
   if (b_writepb(vol, bnum, &b, 1) == -1)
     goto fail;
@@ -255,10 +243,7 @@ int l_getbb(hfsvol *vol, BootBlkHdr *bb, byte *bootcode)
   d_fetchsl(&ptr, &bb->bbSysHeapExtra);
   d_fetchsl(&ptr, &bb->bbSysHeapFract);
 
-# ifdef DEBUG
-  if (ptr - b != 148)
-    abort();
-# endif
+  ASSERT(ptr - b == 148);
 
   if (bootcode)
     {
@@ -307,10 +292,7 @@ int l_putbb(hfsvol *vol, const BootBlkHdr *bb, const byte *bootcode)
   d_storesl(&ptr, bb->bbSysHeapExtra);
   d_storesl(&ptr, bb->bbSysHeapFract);
 
-# ifdef DEBUG
-  if (ptr - b != 148)
-    abort();
-# endif
+  ASSERT(ptr - b == 148);
 
   if (bootcode)
     memcpy(ptr, bootcode, HFS_BOOTCODE1LEN);
@@ -363,10 +345,7 @@ int l_getmdb(hfsvol *vol, MDB *mdb, int backup)
 
   d_fetchstr(&ptr, mdb->drVN, sizeof(mdb->drVN));
 
-# ifdef DEBUG
-  if (ptr - b != 64)
-    abort();
-# endif
+  ASSERT(ptr - b == 64);
 
   d_fetchsl(&ptr, &mdb->drVolBkUp);
   d_fetchsw(&ptr, &mdb->drVSeqNum);
@@ -380,10 +359,7 @@ int l_getmdb(hfsvol *vol, MDB *mdb, int backup)
   for (i = 0; i < 8; ++i)
     d_fetchsl(&ptr, &mdb->drFndrInfo[i]);
 
-# ifdef DEBUG
-  if (ptr - b != 124)
-    abort();
-# endif
+  ASSERT(ptr - b == 124);
 
   d_fetchuw(&ptr, &mdb->drVCSize);
   d_fetchuw(&ptr, &mdb->drVBMCSize);
@@ -397,10 +373,7 @@ int l_getmdb(hfsvol *vol, MDB *mdb, int backup)
       d_fetchuw(&ptr, &mdb->drXTExtRec[i].xdrNumABlks);
     }
 
-# ifdef DEBUG
-  if (ptr - b != 146)
-    abort();
-# endif
+  ASSERT(ptr - b == 146);
 
   d_fetchul(&ptr, &mdb->drCTFlSize);
 
@@ -410,10 +383,7 @@ int l_getmdb(hfsvol *vol, MDB *mdb, int backup)
       d_fetchuw(&ptr, &mdb->drCTExtRec[i].xdrNumABlks);
     }
 
-# ifdef DEBUG
-  if (ptr - b != 162)
-    abort();
-# endif
+  ASSERT(ptr - b == 162);
 
   return 0;
 
@@ -447,10 +417,7 @@ int l_putmdb(hfsvol *vol, const MDB *mdb, int backup)
 
   d_storestr(&ptr, mdb->drVN, sizeof(mdb->drVN));
 
-# ifdef DEBUG
-  if (ptr - b != 64)
-    abort();
-# endif
+  ASSERT(ptr - b == 64);
 
   d_storesl(&ptr, mdb->drVolBkUp);
   d_storesw(&ptr, mdb->drVSeqNum);
@@ -464,10 +431,7 @@ int l_putmdb(hfsvol *vol, const MDB *mdb, int backup)
   for (i = 0; i < 8; ++i)
     d_storesl(&ptr, mdb->drFndrInfo[i]);
 
-# ifdef DEBUG
-  if (ptr - b != 124)
-    abort();
-# endif
+  ASSERT(ptr - b == 124);
 
   d_storeuw(&ptr, mdb->drVCSize);
   d_storeuw(&ptr, mdb->drVBMCSize);
@@ -481,10 +445,7 @@ int l_putmdb(hfsvol *vol, const MDB *mdb, int backup)
       d_storeuw(&ptr, mdb->drXTExtRec[i].xdrNumABlks);
     }
 
-# ifdef DEBUG
-  if (ptr - b != 146)
-    abort();
-# endif
+  ASSERT(ptr - b == 146);
 
   d_storeul(&ptr, mdb->drCTFlSize);
 
@@ -494,10 +455,7 @@ int l_putmdb(hfsvol *vol, const MDB *mdb, int backup)
       d_storeuw(&ptr, mdb->drCTExtRec[i].xdrNumABlks);
     }
 
-# ifdef DEBUG
-  if (ptr - b != 162)
-    abort();
-# endif
+  ASSERT(ptr - b == 162);
 
   memset(ptr, 0, HFS_BLOCKSZ - (ptr - b));
 
