@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: volume.c,v 1.21 1997/11/07 16:46:38 rob Exp $
+ * $Id: volume.c,v 1.26 1998/01/09 16:18:24 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -112,6 +112,58 @@ fail:
   return -1;
 }
 
+/*
+ * NAME:	flushvol()
+ * DESCRIPTION:	flush all pending changes (B*-tree, MDB, VBM) to volume
+ */
+static
+int flushvol(hfsvol *vol)
+{
+  if (vol->flags & HFS_VOL_READONLY)
+    goto done;
+
+  if ((vol->ext.flags & HFS_BT_UPDATE_HDR) &&
+      bt_writehdr(&vol->ext) == -1)
+    goto fail;
+
+  if ((vol->cat.flags & HFS_BT_UPDATE_HDR) &&
+      bt_writehdr(&vol->cat) == -1)
+    goto fail;
+
+  if ((vol->flags & HFS_VOL_UPDATE_VBM) &&
+      v_writevbm(vol) == -1)
+    goto fail;
+
+  if ((vol->flags & (HFS_VOL_UPDATE_MDB | HFS_VOL_UPDATE_ALTMDB)) &&
+      v_writemdb(vol) == -1)
+    goto fail;
+
+done:
+  return 0;
+
+fail:
+  return -1;
+}
+
+/*
+ * NAME:	vol->flush()
+ * DESCRIPTION:	commit all pending changes to volume device
+ */
+int v_flush(hfsvol *vol)
+{
+  if (flushvol(vol) == -1)
+    goto fail;
+
+  if ((vol->flags & HFS_VOL_USECACHE) &&
+      b_flush(vol) == -1)
+    goto fail;
+
+  return 0;
+
+fail:
+  return -1;
+}
+
 /*
  * NAME:	vol->close()
  * DESCRIPTION:	close access path to volume source
@@ -120,17 +172,43 @@ int v_close(hfsvol *vol)
 {
   int result = 0;
 
-  if (vol->flags & HFS_VOL_OPEN)
+  if (! (vol->flags & HFS_VOL_OPEN))
+    goto done;
+
+  if (vol->flags & HFS_VOL_MOUNTED)
     {
-      if (vol->flags & HFS_VOL_USECACHE)
-	result = b_finish(vol);
+      if (! (vol->mdb.drAtrb & HFS_ATRB_UMOUNTED))
+	{
+	  vol->mdb.drAtrb |= HFS_ATRB_UMOUNTED;
+	  vol->flags |= HFS_VOL_UPDATE_MDB;
+	}
 
-      vol->flags &= ~HFS_VOL_OPEN;
-
-      if (os_close(&vol->priv) == -1)
+      if (flushvol(vol) == -1)
 	result = -1;
     }
 
+  if ((vol->flags & HFS_VOL_USECACHE) &&
+      b_finish(vol) == -1)
+    result = -1;
+
+  if (os_close(&vol->priv) == -1)
+    result = -1;
+
+  vol->flags &= ~(HFS_VOL_OPEN | HFS_VOL_MOUNTED);
+
+  /* free dynamically allocated structures */
+
+  FREE(vol->vbm);
+
+  vol->vbm = 0;
+
+  FREE(vol->ext.map);
+  FREE(vol->cat.map);
+
+  vol->ext.map = 0;
+  vol->cat.map = 0;
+
+done:
   return result;
 }
 
@@ -176,12 +254,13 @@ int v_geometry(hfsvol *vol, int pnum)
   vol->vstart = map.pmPyPartStart;
   vol->vlen   = map.pmPartBlkCnt;
 
-  if (map.pmDataCnt > 0)
+  if (map.pmDataCnt)
     {
-      if (map.pmLgDataStart + map.pmDataCnt > map.pmPartBlkCnt)
+      if ((unsigned long) map.pmLgDataStart +
+	  (unsigned long) map.pmDataCnt > vol->vlen)
 	ERROR(EINVAL, "partition data overflows partition");
 
-      vol->vstart += map.pmLgDataStart;
+      vol->vstart += (unsigned long) map.pmLgDataStart;
       vol->vlen    = map.pmDataCnt;
     }
 
@@ -294,10 +373,7 @@ int v_readvbm(hfsvol *vol)
   int vbmsz = (vol->mdb.drNmAlBlks + 4095) / 4096;
   block *bp;
 
-# ifdef DEBUG
-  if (vol->vbm)
-    abort();
-# endif
+  ASSERT(vol->vbm == 0);
 
   if (vol->mdb.drAlBlSt - vbmst < vbmsz)
     ERROR(EIO, "volume bitmap collides with volume data");
@@ -345,6 +421,43 @@ fail:
   return -1;
 }
 
+/*
+ * NAME:	vol->mount()
+ * DESCRIPTION:	load volume information into memory
+ */
+int v_mount(hfsvol *vol)
+{
+  /* read the MDB, volume bitmap, and extents/catalog B*-tree headers */
+
+  if (v_readmdb(vol) == -1 ||
+      v_readvbm(vol) == -1 ||
+      bt_readhdr(&vol->ext) == -1 ||
+      bt_readhdr(&vol->cat) == -1)
+    goto fail;
+
+  if (! (vol->mdb.drAtrb & HFS_ATRB_UMOUNTED))
+    {
+      /* volume was not cleanly unmounted; scavenge free-space */
+
+      if (v_scavenge(vol) == -1)
+	goto fail;
+    }
+
+  if (vol->mdb.drAtrb & HFS_ATRB_SLOCKED)
+    vol->flags |= HFS_VOL_READONLY;
+  else if (vol->flags & HFS_VOL_READONLY)
+    vol->mdb.drAtrb |= HFS_ATRB_HLOCKED;
+  else
+    vol->mdb.drAtrb &= ~HFS_ATRB_HLOCKED;
+
+  vol->flags |= HFS_VOL_MOUNTED;
+
+  return 0;
+
+fail:
+  return -1;
+}
+
 /*
  * NAME:	vol->catsearch()
  * DESCRIPTION:	search catalog tree
@@ -503,10 +616,7 @@ int v_allocblocks(hfsvol *vol, ExtDescriptor *blocks)
   end     = vol->mdb.drNmAlBlks;
   vbm     = vol->vbm;
 
-# ifdef DEBUG
-  if (request == 0)
-    abort();
-# endif
+  ASSERT(request > 0);
 
   /* backtrack the start pointer to recover unused space */
 
@@ -863,49 +973,6 @@ fail:
   return -1;
 }
 
-/*
- * NAME:	vol->flush()
- * DESCRIPTION:	flush all pending changes (B*-tree, MDB, VBM) to volume
- */
-int v_flush(hfsvol *vol, int umounting)
-{
-  if (vol->flags & HFS_VOL_READONLY)
-    goto done;
-
-  if ((vol->ext.flags & HFS_BT_UPDATE_HDR) &&
-      bt_writehdr(&vol->ext) == -1)
-    goto fail;
-
-  if ((vol->cat.flags & HFS_BT_UPDATE_HDR) &&
-      bt_writehdr(&vol->cat) == -1)
-    goto fail;
-
-  if ((vol->flags & HFS_VOL_UPDATE_VBM) &&
-      v_writevbm(vol) == -1)
-    goto fail;
-
-  if (umounting &&
-      ! (vol->mdb.drAtrb & HFS_ATRB_UMOUNTED))
-    {
-      vol->mdb.drAtrb |= HFS_ATRB_UMOUNTED;
-      vol->flags |= HFS_VOL_UPDATE_MDB;
-    }
-
-  if ((vol->flags & (HFS_VOL_UPDATE_MDB | HFS_VOL_UPDATE_ALTMDB)) &&
-      v_writemdb(vol) == -1)
-    goto fail;
-
-  if ((vol->flags & HFS_VOL_USECACHE) &&
-      b_flush(vol) == -1)
-    goto fail;
-
-done:
-  return 0;
-
-fail:
-  return -1;
-}
-
 /*
  * NAME:	markexts()
  * DESCRIPTION:	set bits from an extent record in the volume bitmap
