@@ -1,6 +1,6 @@
 /*
  * librsrc - library for reading and writing Macintosh resources
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: rsrc.c,v 1.10 1997/10/30 05:57:25 rob Exp $
+ * $Id: rsrc.c,v 1.10 1997/10/30 05:57:25 rob Exp rob $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -34,10 +34,10 @@
 const char *rsrc_error = "no error";	/* static error string */
 
 /*
- * NAME:	rsrc->open()
+ * NAME:	rsrc->init()
  * DESCRIPTION:	initialize access to a resource file
  */
-rsrcfile *rsrc_open(void *priv, const struct rsrcprocs *procs)
+rsrcfile *rsrc_init(void *priv, const struct rsrcprocs *procs)
 {
   rsrcfile *rfile;
   byte head[16];
@@ -112,10 +112,10 @@ fail:
 }
 
 /*
- * NAME:	rsrc->close()
+ * NAME:	rsrc->finish()
  * DESCRIPTION:	terminate access to a resource file
  */
-int rsrc_close(rsrcfile *rfile)
+int rsrc_finish(rsrcfile *rfile)
 {
   FREE(rfile->map.data);
   FREE(rfile);
