@@ -1,6 +1,6 @@
 /*
  * librsrc - library for reading and writing Macintosh resources
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: rsrc.h,v 1.6 1997/09/18 22:39:14 rob Exp $
+ * $Id: rsrc.h,v 1.6 1997/09/18 22:39:14 rob Exp rob $
  */
 
 typedef struct _rsrcfile_ rsrcfile;
@@ -37,8 +37,8 @@ struct rsrcprocs {
 # define RSRC_SEEK_CUR		1
 # define RSRC_SEEK_END		2
 
-rsrcfile *rsrc_open(void *, const struct rsrcprocs *);
-int rsrc_close(rsrcfile *);
+rsrcfile *rsrc_init(void *, const struct rsrcprocs *);
+int rsrc_finish(rsrcfile *);
 
 int rsrc_counttypes(rsrcfile *);
 int rsrc_count(rsrcfile *, const char *);
