@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: tclhfs.c,v 1.23 1997/11/11 21:30:42 rob Exp $
+ * $Id: tclhfs.c,v 1.26 1998/01/08 21:17:04 rob Exp rob $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -56,7 +56,7 @@ extern int errno;
 # define REALLOC(ptr, type, n)  \
     ((type *) ((ptr) ? realloc(ptr, SIZE(type, n)) : malloc(SIZE(type, n))))
 # define REALLOCX(ptr, type, n)  \
-    ((n) ? REALLOC(type, n) : (FREE(ptr), (type *) 0))
+    ((n) ? REALLOC(ptr, type, n) : (FREE(ptr), (type *) 0))
 
 # define CHARLEN(type)		((sizeof(type) * CHAR_BIT + 2) / 3 + 1)
 
@@ -738,7 +738,7 @@ int do_zero(const char *path, int nparts, unsigned long *len)
 
 /*
  * NAME:	do_mkpart()
- * DESCRIPTION:	call hfs_mkhfspart() with necessary privileges
+ * DESCRIPTION:	call hfs_mkpart() with necessary privileges
  */
 static
 int do_mkpart(const char *path, unsigned long len)
@@ -1170,7 +1170,9 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 	{
 	  int nparts;
 
+	  suid_enable();
 	  nparts = hfs_nparts(argv[2]);
+	  suid_disable();
 
 	  if (nparts > 1)
 	    {
@@ -1251,13 +1253,19 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
     }
   else if (strcmp(argv[1], "nparts") == 0)
     {
+      int nparts;
+
       if (argc != 3)
 	{
 	  interp->result = "wrong # args";
 	  return TCL_ERROR;
 	}
 
-      sprintf(interp->result, "%d", hfs_nparts(argv[2]));
+      suid_enable();
+      nparts = hfs_nparts(argv[2]);
+      suid_disable();
+
+      sprintf(interp->result, "%d", nparts);
     }
   else if (strcmp(argv[1], "format") == 0)
     {
@@ -1292,7 +1300,8 @@ int cmd_hfs(ClientData clientData, Tcl_Interp *interp,
 
 	  for (i = 0; i < listc; ++i)
 	    {
-	      if (Tcl_ExprLong(interp, listv[i], &badblocks[i]) != TCL_OK)
+	      if (Tcl_ExprLong(interp, listv[i],
+			       (long *) &badblocks[i]) != TCL_OK)
 		{
 		  free(listv);
 		  FREE(badblocks);
