@@ -1,7 +1,6 @@
-###############################################################################
 #
 # hfsutils - tools for reading and writing Macintosh HFS volumes
-# Copyright (C) 1996, 1997 Robert Leslie
+# Copyright (C) 1996-1998 Robert Leslie
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,16 +16,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# $Id: xhfs.tcl,v 1.14 1997/11/11 23:03:46 rob Exp $
+# $Id: xhfs.tcl,v 1.17 1998/01/09 19:30:49 rob Exp rob $
 #
-###############################################################################
 
 set tk_strictMotif 1
 
-set gThinFont		{-*-helvetica-medium-r-normal-*-*-120-*-*-p-*-*-*}
-set gSmallFont		{-*-helvetica-medium-r-normal-*-*-100-*-*-p-*-*-*}
-set gTypeFont		{-*-lucidatypewriter-medium-r-*-*-*-120-*-*-m-*-*-*}
-set gTitleFont		{-*-lucida-bold-i-normal-*-*-250-*-*-p-*-*-*}
+set gNormalFont	{-adobe-helvetica-bold-r-normal-*-*-120-*-*-p-*-iso8859-1}
+set gThinFont	{-adobe-helvetica-medium-r-normal-*-*-120-*-*-p-*-iso8859-1}
+set gSmallFont	{-adobe-helvetica-medium-r-normal-*-*-100-*-*-p-*-iso8859-1}
+set gTypeFont	{-*-lucidatypewriter-medium-r-normal-*-*-120-*-*-m-*-iso8859-1}
+set gTitleFont	{-*-lucida-bold-i-normal-*-*-250-*-*-p-*-iso8859-1}
 
 set gDefaultDevice	/dev/fd0
 set gLowFormatCmd	[list fdformat $gDefaultDevice]
@@ -34,6 +33,8 @@ set gMountSide		.l
 set gFlushInterval	30000
 set gDfCmd		[list df]
 
+option add *Font $gNormalFont
+
 ###############################################################################
 
 # Set architecture defaults
@@ -197,7 +198,7 @@ proc copy_directory {srcvol name dstvol copyproc modeproc} {
     $dstvol chdir $name
 
     foreach ind [$srcvol dir] {
-	assoc $ind item
+	array set item $ind
 
 	if {$item(kind) == "directory"} {
 	    copy_directory $srcvol $item(name) $dstvol $copyproc $modeproc
@@ -222,7 +223,7 @@ proc delete_directory {vol name} {
     $vol chdir $name
 
     foreach ind [$vol dir] {
-	assoc $ind item
+	array set item $ind
 
 	if {$item(kind) == "directory"} {
 	    delete_directory $vol $item(name)
@@ -266,7 +267,7 @@ proc do_copy {side other} {
     set needupdate 0
 
     foreach ind $sel {
-	assoc [lindex $dir($side) $ind] item
+	array set item [lindex $dir($side) $ind]
 
 	$box see $ind
 
@@ -340,7 +341,7 @@ proc do_rename {side} {
 
     set box $side.mid.lb
     set sel [$box curselection]
-    assoc [lindex $dir($side) [lindex $sel 0]] item
+    array set item [lindex $dir($side) [lindex $sel 0]]
 
     set w [dialog "Rename" "Cancel" "Rename" 1]
     $w.bot.ok config -command [list rename2 $w $side]
@@ -391,7 +392,7 @@ proc do_delete {side} {
     set needupdate 0
 
     foreach ind $sel {
-	assoc [lindex $dir($side) $ind] item
+	array set item [lindex $dir($side) $ind]
 
 	$box see $ind
 
@@ -629,7 +630,8 @@ proc ufs_automode {vol array} {
 	return raw
     } else {
 	cd [$vol cwd]
-	if {[catch {exec file -L $name} type] == 0 &&  \
+	if {([catch {exec file -L $name} type] == 0 ||  \
+		[catch {exec file $name} type] == 0) &&  \
 		[regexp {text|commands} $type]} {
 	    return text
 	}
@@ -638,19 +640,6 @@ proc ufs_automode {vol array} {
     }
 } 
 
-proc assoc {list var} {
-    upvar $var array
-
-    foreach elt $list {
-	if {[info exists key]} {
-	    set array($key) $elt
-	    unset key
-	} else {
-	    set key $elt
-	}
-    }
-}
-
 proc watch_cursor {{w "."} {default "left_ptr"}} {
     $w config -cursor watch
     if {[string compare $w "."] != 0} {
@@ -687,7 +676,7 @@ proc updatelist {side} {
     set sepchar [$vol($side) sepchar]
 
     foreach ent $list {
-	assoc $ent item
+	array set item $ent
 
 	set name [eval $chartrans [list $item(name)]]
 
@@ -1078,7 +1067,7 @@ proc size {bytes} {
 proc show_info {vol list} {
     global gTypeFont gThinFont
 
-    assoc $list info
+    array set info $list
 
     set isdir [expr [string compare $info(kind) "directory"] == 0]
     set ishfs [info exists info(crdate)]
@@ -1711,7 +1700,7 @@ proc wclick {side copytext} {
 	.m.2.ops.rena config -state disabled
 	.m.2.ops.dele config -state disabled
     } elseif {[llength $sel] == 1} {
-	assoc [lindex $dir($side) [lindex $sel 0]] item
+	array set item [lindex $dir($side) [lindex $sel 0]]
 
 	switch -glob $item(kind) {
 	    directory {
@@ -1760,7 +1749,7 @@ proc wclick {side copytext} {
 	if {$gAutoModeSelect &&  \
 		[.m.3.mode.auto cget -state] != "disabled"} {
 	    foreach ind $sel {
-		assoc [lindex $dir($side) $ind] item
+		array set item [lindex $dir($side) $ind]
 		set auto [$fstype($side)_automode $vol($side) item]
 
 		if {[info exists mode]} {
